//Set working directory (change to your directory containing "government_responsiveness_council_replication.dta")
cd "/CHANGE"

 
///////////////////////
//Install Packages
///////////////////////

//Script stops if already installed - PLEASE RESTART SCRIPT AGAIN
ssc install outreg
ssc install estout


///////////////////////
//Preparation of Data
///////////////////////

//Load data
use "government_responsiveness_council_replication.dta", clear

//Preparation (get rid of observations with missing data on IV or main DV, set random effect), restricts sample to autumn 2011
xtset act
drop if eum_lag6m == .
drop if opposition_vote == .
  
//Produce TABLE 1 in the Paper ----> Show Wordscores by area and save to RTF file
estpost tabstat ws_policy_rescaled, by(area) statistics(mean) columns(statistics) 
esttab using descriptives.rtf, replace cells("mean") label 

//Produce TABLE A1 in the Web Appendix ----> Show distribution of votes by policy area and save to RTF file
estpost tab area if opposition_vote != .
esttab using descriptives.rtf, append cells("b(label(freq)) pct(fmt(2)) cumpct(fmt(2))") varlabels(, blist(Total "")) nonumber nomtitle noobs label 

//Produce FIGURE A1 in the Web Appendix ----> Plot number and percentage of opposition votes by country and save as PNG file
egen no_opp_votes = sum(opposition_vote), by(government)
graph bar (mean) no_opp_votes, over(government, sort(no_opp_v)) ytitle(Number of opposition votes) scheme(lean2) ylabel(0 (20) 80)
egen perc_opp_votes = mean(opposition_vote * 100), by(government)
graph bar (mean) perc_opp_v, over(government, sort(perc_opp_v)) ytitle(Percentage of opposition votes) scheme(lean2) ylabel(0 (0.5) 3.5)
graph save Graph "FIGURE_A1_Web_Appendix.gph", replace
graph export "FIGURE_A1_Web_Appendix.png", replace


///////////////
//Main Models 
///////////////

//Estimate MODEL 1 from TABLE 2 in the Paper ----> Base model without party positions, save to DOC file
xtlogit opposition_vote c.eum_lag6m inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency i.country if change_salience != . & area != 1 & area != 6 & area != 10, re 
outreg using "council_regression.doc", replace starlevels(10 5 1 0.1) se

//Estimate MODEL 2 from TABLE 2 in the Paper ----> Base model with party positions, add to DOC file
xtlogit opposition_vote c.eum_lag6m gov_eu_cmp_static gov_lr_cmp_static inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency i.country if change_salience != . & area != 1 & area != 6 & area != 10, re
outreg using "council_regression.doc", merge starlevels(10 5 1 0.1) se

//Estimate MODEL 3 from TABLE 2 in the Paper ----> Including interaction with change in party salience, add to DOC FILE
xtlogit opposition_vote c.change_salience##c.eum_lag6m gov_eu_cmp_static gov_lr_cmp_static inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency i.country if change_salience != . & area != 1 & area != 6 & area != 10, re 
outreg using "council_regression.doc", merge starlevels(10 5 1 0.1) se

//Produce FIGURE 1 in the Paper ----> Estimate marginal effects, plot, and save as PNG file
margins, dydx(eum_lag6m) at(change_salience = (-.34 (0.02) .30)) predict(pu0)
marginsplot, scheme(lean2) recast(line) recastci(rline) yline(0, lcolor(gs12) lwidth(vthin)) ylabel(,glcolor(none) glwidth(vvthin)) ciopts(lpattern(longdash)) plot1opts(mcolor(gs10) lcolor(gs5)) xtitle("Change in party salience of EU integration") ytitle("Marginal effect of public opinion" "on probability of opposition vote") xlabel(-.34 (0.1) 0.3) ylabel(-.03 (0.01) .02) title("")
graph save Graph "FIGURE_1_Paper.gph", replace
graph export "FIGURE_1_Paper.png", replace

//Construct indicator for estimation sample
gen sample = 1 if e(sample) == 1

//Show standard deviation of opinion within countries
egen sd = sd(eum_lag6m), by(country)
sum sd, detail

//Produce TABLE A2 in the Web Appendix ----> Get descriptives on all covariates in the estimation sample and save to RTF file
estpost sum opposition_vote change_salience eum_lag6m gov_eu_cmp_static gov_lr_cmp_static inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency if sample == 1
esttab using descriptives.rtf, append cells("mean sd min max") nomtitle nonumber label

//Show distribution of votes by policy area in estimation sample
estpost tab area if sample == 1
esttab using descriptives.rtf, append cells("b(label(freq)) pct(fmt(2)) cumpct(fmt(2))") varlabels(, blist(Total "")) nonumber nomtitle noobs label 


/////////////////////
//Robustness checks
/////////////////////

//Estimate MODEL A1 from TABLE A8.1 in the Web Appendix ----> Policy area fixed effects, save to DOC file
xtlogit opposition_vote c.change_salience##c.eum_lag6m gov_eu_cmp_static gov_lr_cmp_static inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency i.country i.area if change_salience != . & area != 1 & area != 6 & area != 10, re
outreg using "council_robustness.doc", replace starlevels(10 5 1 0.1) se

//Estimate MODEL A2 from TABLE A8.1 in the Web Appendix ----> Excluding fixed effects, save to DOC file
xtlogit opposition_vote c.change_salience##c.eum_lag6m gov_eu_cmp_static gov_lr_cmp_static inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency if change_salience != . & area != 1 & area != 6 & area != 10, re
outreg using "council_robustness.doc", merge starlevels(10 5 1 0.1) se

//Estimate MODEL A3 from TABLE A8.1 in the Web Appendix ----> Random effect for vote number, save to DOC file
xtset vote_no
xtlogit opposition_vote c.change_salience##c.eum_lag6m gov_eu_cmp_static gov_lr_cmp_static inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency i.country if change_salience != . & area != 1 & area != 6 & area != 10, re
outreg using "council_robustness.doc", merge starlevels(10 5 1 0.1) se
xtset act

//Estimate MODEL A4 from TABLE A8.1 in the Web Appendix ----> 'No' votes only (takes very long to converge, second model without FEs for countries), save to DOC file
xtlogit no_vote c.change_salience##c.eum_lag6m gov_eu_cmp_static gov_lr_cmp_static inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency i.country if change_salience != . & area != 1 & area != 6 & area != 10, re
outreg using "council_robustness.doc", merge starlevels(10 5 1 0.1) se
xtlogit no_vote c.change_salience##c.eum_lag6m gov_eu_cmp_static gov_lr_cmp_static inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency if change_salience != . & area != 1 & area != 6 & area != 10, re

//Estimate MODEL A5 from TABLE A8.1 in the Web Appendix ----> 4-year change in salience, save to DOC file
xtlogit opposition_vote c.change_salience_4##c.eum_lag6m gov_eu_cmp_static gov_lr_cmp_static inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency i.country if change_salience != . & area != 1 & area != 6 & area != 10, re 
outreg using "council_robustness.doc",merge starlevels(10 5 1 0.1) se

//Estimate MODEL A6 from TABLE A8.1 in the Web Appendix ----> Seat-weighted change in salience, save to DOC file
xtlogit opposition_vote c.change_salience_w##c.eum_lag6m gov_eu_cmp_static gov_lr_cmp_static inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency i.country if change_salience != . & area != 1 & area != 6 & area != 10, re
outreg using "council_robustness.doc", merge starlevels(10 5 1 0.1) se

//Estimate MODEL A7 from TABLE A8.1 in the Web Appendix ----> 3-month lag of opinion, save to DOC file
xtlogit opposition_vote c.change_salience##c.eum_lag3m gov_eu_cmp_static gov_lr_cmp_static inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency i.country if change_salience != . & area != 1 & area != 6 & area != 10, re 
outreg using "council_robustness.doc", merge starlevels(10 5 1 0.1) se

//Estimate MODEL A8 from TABLE A8.1 in the Web Appendix ----> 1-year lag of opinion, save to DOC file
xtlogit opposition_vote c.change_salience##c.eum_lag1y gov_eu_cmp_static gov_lr_cmp_static inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency i.country if change_salience != . & area != 1 & area != 6 & area != 10, re
outreg using "council_robustness.doc", merge starlevels(10 5 1 0.1) se

//Estimate MODEL A9 from TABLE A8.2 in the Web Appendix ----> 18-month lag of opinion, save to DOC file
xtlogit opposition_vote c.change_salience##c.eum_lag18m gov_eu_cmp_static gov_lr_cmp_static inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency i.country if change_salience != . & area != 1 & area != 6 & area != 10, re
outreg using "council_robustness2.doc", replace starlevels(10 5 1 0.1) se
   
//Estimate MODEL A10 from TABLE A8.2 in the Web Appendix ----> Sensitivity with regard to policy areas (exclusion of areas), save to DOC file
xtlogit opposition_vote c.change_salience##c.eum_lag6m gov_eu_cmp_static gov_lr_cmp_static inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency i.country if change_salience != . & area != 1 & area != 6 & area != 10 & area != 5 & area != 8, re 
outreg using "council_robustness2.doc", merge starlevels(10 5 1 0.1) se

//Estimate MODEL A11 from TABLE A8.2 in the Web Appendix ----> Sensitivity with regard to policy areas (inclusion of areas), save to DOC file
xtlogit opposition_vote c.change_salience##c.eum_lag6m gov_eu_cmp_static gov_lr_cmp_static inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency i.country if change_salience != . & area != 1 & area != 6, re 
outreg using "council_robustness2.doc", merge starlevels(10 5 1 0.1) se

//Estimate MODEL A12 from TABLE A8.2 in the Web Appendix ----> Run model on established policy areas, save to DOC file
xtlogit opposition_vote c.change_salience##c.eum_lag6m gov_eu_cmp_static gov_lr_cmp_static inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency i.country if change_salience != . & (area == 1 | area == 6 | area == 10), re 
outreg using "council_robustness2.doc", merge starlevels(10 5 1 0.1) se
  
//Estimate MODEL A13 from TABLE A8.2 in the Web Appendix ----> Jackknife resampling on country level, save to DOC file
xtset country
jackknife, cluster(country): xtlogit opposition_vote c.change_salience##c.eum_lag6m gov_eu_cmp_static gov_lr_cmp_static inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency if change_salience != . & area != 1 & area != 6 & area != 10, fe
outreg using "council_robustness2.doc", merge starlevels(10 5 1 0.1) se

//Estimate MODEL A14 from TABLE A8.2 in the Web Appendix ----> Excluding enlargement dummy, save to DOC file
xtset act
xtlogit opposition_vote c.change_salience##c.eum_lag6m gov_eu_cmp_static gov_lr_cmp_static inflation_wb unemployment_wb eu_cont_pc codecision presidency i.country if change_salience != . & area != 1 & area != 6 & area != 10, re
outreg using "council_robustness2.doc", merge starlevels(10 5 1 0.1) se

//Estimate MODEL A15 from TABLE A8.2 in the Web Appendix ----> Multiple imputation of missing CMP measures, save to DOC file
//Create interaction as 'just another variable'
gen int_change_salience = eum_lag6m * change_salience
drop if eum_lag6m == .
drop if opposition_vote == .
drop if area == 1
drop if area == 6
drop if area == 10
xtset act
mi set flong
mi register imputed gov_lr_cmp_static gov_eu_cmp_static change_salience int_change_salience
set seed 12345
mi impute chained (pmm) gov_lr_cmp_static gov_eu_cmp_static change_salience int_change_salience = c.eum_lag6m i.country i.area opposition_vote inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency, add(5) force

mi estimate (sal1: _b[eum_lag6m]+ (-.33) * _b[int_change_salience]) (sal2: _b[eum_lag6m]+ (-.08) * _b[int_change_salience]) (sal3: _b[eum_lag6m]+ (.29) * _b[int_change_salience]), post: xtlogit opposition_vote eum_lag6m change_salience int_change_salience gov_eu_cmp_static gov_lr_cmp_static inflation_wb unemployment_wb eu_cont_pc codecision enlargement presidency i.country, re
outreg using "council_robustness2.doc", merge starlevels(10 5 1 0.1) se


//////////////////////
//Topic Model Tables
//////////////////////

//Load data
use "government_responsiveness_council_replication.dta", clear

//Generate likely topic indicator
tab lda_likely_topic, gen(topic)

//Produce parts of TABLE 3 in the Paper ----> Get 'Difference by opinion (%)' tests by topic
prtest opposition_vote if topic1 == 1, by(below_mean_opinion)
prtest opposition_vote if topic2 == 1, by(below_mean_opinion)
prtest opposition_vote if topic3 == 1, by(below_mean_opinion)
prtest opposition_vote if topic4 == 1, by(below_mean_opinion)
prtest opposition_vote if topic5 == 1, by(below_mean_opinion)
prtest opposition_vote if topic6 == 1, by(below_mean_opinion)
prtest opposition_vote if topic7 == 1, by(below_mean_opinion)
prtest opposition_vote if topic8 == 1, by(below_mean_opinion)
prtest opposition_vote if topic9 == 1, by(below_mean_opinion)
prtest opposition_vote if topic10 == 1, by(below_mean_opinion)
prtest opposition_vote if topic11 == 1, by(below_mean_opinion)
prtest opposition_vote if topic12 == 1, by(below_mean_opinion)
prtest opposition_vote if topic13 == 1, by(below_mean_opinion)
prtest opposition_vote if topic14 == 1, by(below_mean_opinion)
//Topic 15 stops script due to no opposition vote - RESTART SCRIPT
prtest opposition_vote if topic15 == 1, by(below_mean_opinion)
prtest opposition_vote if topic16 == 1, by(below_mean_opinion)
prtest opposition_vote if topic17 == 1, by(below_mean_opinion)
prtest opposition_vote if topic18 == 1, by(below_mean_opinion)
prtest opposition_vote if topic19 == 1, by(below_mean_opinion)
prtest opposition_vote if topic20 == 1, by(below_mean_opinion)
prtest opposition_vote if topic21 == 1, by(below_mean_opinion)
prtest opposition_vote if topic22 == 1, by(below_mean_opinion)
prtest opposition_vote if topic23 == 1, by(below_mean_opinion)
prtest opposition_vote if topic24 == 1, by(below_mean_opinion)
prtest opposition_vote if topic25 == 1, by(below_mean_opinion)
prtest opposition_vote if topic26 == 1, by(below_mean_opinion)
prtest opposition_vote if topic27 == 1, by(below_mean_opinion)
prtest opposition_vote if topic28 == 1, by(below_mean_opinion)
prtest opposition_vote if topic29 == 1, by(below_mean_opinion)
prtest opposition_vote if topic30 == 1, by(below_mean_opinion)
prtest opposition_vote if topic31 == 1, by(below_mean_opinion)
prtest opposition_vote if topic32 == 1, by(below_mean_opinion)
prtest opposition_vote if topic33 == 1, by(below_mean_opinion)
prtest opposition_vote if topic34 == 1, by(below_mean_opinion)
prtest opposition_vote if topic35 == 1, by(below_mean_opinion)
prtest opposition_vote if topic36 == 1, by(below_mean_opinion)
prtest opposition_vote if topic37 == 1, by(below_mean_opinion)
prtest opposition_vote if topic38 == 1, by(below_mean_opinion)
prtest opposition_vote if topic39 == 1, by(below_mean_opinion)
prtest opposition_vote if topic40 == 1, by(below_mean_opinion)
//Topic 41 stops script due to no opposition vote - RESTART SCRIPT
prtest opposition_vote if topic41 == 1, by(below_mean_opinion)
prtest opposition_vote if topic42 == 1, by(below_mean_opinion)
prtest opposition_vote if topic43 == 1, by(below_mean_opinion)
prtest opposition_vote if topic44 == 1, by(below_mean_opinion)
prtest opposition_vote if topic45 == 1, by(below_mean_opinion)

//Produce parts of TABLE 3 in the Paper ----> Get 'Obs. (%)' by topic and save to RTF file
estpost tab lda_likely_topic 
esttab using descriptives_topics.rtf, replace cells("b(label(freq)) pct(fmt(2)) cumpct(fmt(2))") varlabels(, blist(Total "")) nonumber nomtitle noobs label 

//Produce parts of TABLE 3 in the Paper ----> Get 'Opposition votes (%)' by topic 
tab lda_likely_topic opposition_vote, row 

/**** NOTE: 'Key words' by topic for TABLE 3 in the Paper are a subset of the most frequent words by topic produced by the LDA model (in R) and are saved in "lda45final_terms.csv" ****/


//////////////////////
//Media Data Analysis
//////////////////////

//Load data
use "government_responsiveness_council_replication.dta", clear

//Get rid of countries not needed, acts for which media information is missing, and non-codecision files
drop if (government != "uk" & government != "de" & government != "ie" & government != "fr" & government != "be" & government != "it" & government != "at")
collapse (mean) media codecision enlargement year lda_likely_topic area (sum) opposition_vote, by(inter_file_no)
drop if media == .
drop if codecision != 1

//Generate media measures (logged number and binary)
gen log_media = log(media + 1)
gen bin_media = .
replace bin_media = 0 if media == 0
replace bin_media = 1 if media != . & media != 0

//Generate binary opposition measure for whether any country opposed
gen bin_opp = .
replace bin_opp = 0 if opposition == 0
replace bin_opp = 1 if opposition != . & opposition != 0

//Estimate 'OLS' MODEL in TABLE A7 in the Web Appendix ----> Model of logged media reports with topic FE, save to DOC file
reg log_media opposition_vote i.lda_likely_topic
outreg using "council_media.doc", replace starlevels(10 5 1 0.1) se

//Produce FIGURE 2 in the Paper ----> Estimate marginal effects, plot, and save as PNG file
margins, at(opposition_vote = (0 1 2 3)) expression(exp(predict(xb))-1)
marginsplot, scheme(lean2) recast(line) recastci(rline) ylabel(,glcolor(none) glwidth(vvthin)) ciopts(lpattern(longdash)) plot1opts(mcolor(gs10) lcolor(gs5)) xtitle("Number of opposition votes") ytitle("Average number of newspaper stories") xlabel(0 (1) 3) ylabel(0 (0.5) 2.5) title("")
graph save Graph "FIGURE_2_Paper.gph", replace
graph export "FIGURE_2_Paper.png", replace

//Estimate 'Logistic Regression' MODEL in Table A7 in the Web Appendix ----> Model of media coverage (binary) with topic RE, save to DOC file
xtset lda_likely_topic
xtlogit bin_media opposition_vote, re
outreg using "council_media.doc", merge starlevels(10 5 1 0.1) se

//Estimate marginal effects and plot
margins, at(opposition_vote = (0 1 2 3)) predict(pu0)
marginsplot, scheme(lean2) recast(line) recastci(rline) ylabel(,glcolor(none) glwidth(vvthin)) ciopts(lpattern(longdash)) plot1opts(mcolor(gs10) lcolor(gs5)) xtitle("Number of opposition votes") ytitle("Probability of newspaper coverage") xlabel(0 (1) 3) ylabel(0 (0.1) 1) title("")


/////////////////////
//Additional graphs
/////////////////////

//Produce FIGURE A2 in the Web Appendix ----> Change in party salience over time (France)
use "france_change_salience.dta", clear
format date %dm_Y
gen change_salience =  sys_eu_sal_mean_dynamic -  sys_eu_sal_mean_dynamic_lag2
twoway (line change_salience date if government == "France" & date <= date("01/01/2010", "DMY") & date >= date("01/01/1993", "DMY"), scheme(lean2) xtitle(" ") ytitle("Change in party salience") lwidth(thick))
graph save Graph "FIGURE_A2_Web_Appendix.gph", replace
graph export "FIGURE_A2_Web_Appendix.png", replace
